# ParsTalk

ParsTalk is a simple Python library to convert Persian (Farsi) text to Finglish with vowel detection and optionally play it as speech.
Please use punctuation marks for this library to function properly.
Thanks.

## Installation

```bash
pip install parstalk
```

## Usage

```python
from parstalk import farsi_to_finglish_with_vowels

text = "سَلام"
print(farsi_to_finglish_with_vowels(text))
```

## License
MIT
